@@ -13,7 +13,7 @@ use UNIVERSAL::require;
 # hence all the map {''.$_} column filters. Some of them are probably unnecessary, 
 # but I need to track down which.
 
-our $VERSION = '0.34';
+our $VERSION = '0.341';
 
 our @BASIC_FORM_MODIFIERS = qw( hidden options file );
 
@@ -2048,7 +2048,7 @@ David Baird, C<< <cpan@riverside-cms.co.uk> >>
 
 Please report any bugs or feature requests to
 C<bug-class-dbi-plugin-formbuilder@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Class-DBI-Plugin-FormBuilder>.
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Class-DBI-FormBuilder>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
